#!/bin/sh
usage() {
cat <<EOF
Usage: menuuser [-x] {-q|-u|-a|-z|-c} [-g gid] [-v priv] [-n name]
       [-m menu]  [-d menudir] [-i init] [-p phone] [-f fax] uid {uid}

Description: Command to manage the Airpex /edx/MENU.USER file.

Options: -q inquire user
	 -u update user
	 -a add user
	 -c copy user, use -n to supply name
	 -z zap (delete) user
	 -x debug, just output sql command

Examples:

List an existing user:
  menuuser -q -g -n -i -m -d johnd 

Add a new user:
  menuuser -a -g 101 -n 'John Doh' -i 'JD' -m '%MAIN' -d '%MENU' johnd 

Copy a user to another user:
  menuuser -c -n "Jane Doh" johnd janed

Update a user's name:
  menuuser -u -n 'John Smith' johns
EOF
}

test $# -eq 0 && usage && exit 1

BTASDIR=/edx
export BTASDIR

sqlcmd="sql -u"

# Canonicalize userid. If it is not numeric then convert to numeric
# by looking it up in /etc/passwd.
userID() {
echo "$1" | egrep -q '^[0-9]*$'
if test $? -eq 0
then
  echo "$1"
else
  awk -F: '$1 == "'"$1"'" { print $3 ; exit }' /etc/passwd
fi
}

getUser() {
sql -uq <<EOF
select #1 from "/edx/MENU.USER" where #1 = $1;
EOF
}

userExists() {
  u=`getUser $1`
  test "$u" && return 0
  return 1
}

dumpUser() {
sql -qu <<EOF
select * from "/edx/MENU.USER" where #1 = $1;
EOF
}

USERID="$1"
if test $# -eq 1
then
  USERID=$(userID $USERID)
  if userExists $USERID
  then
    dumpUser $USERID
  else
    echo User $USERID does not exist.
  fi
  exit
fi

USERID=""
GROUP=""
PRIV=0
NAME=""
MENU=""
MENUDIR=""
INITIALS=""
PHONE=""
FAX=""
EMAIL=""
COVER=""
WORKGRP=""
SCRNDUMP=""
FAXTPL=""
X1=0
ABINUM=0
export GETGROUP=""

addUser() {
#echo "Creating $USERID"
$sqlcmd <<EOF
insert into "/edx/MENU.USER"
select
$USERID,$GROUP,$PRIV,'$NAME','$MENU','$MENUDIR','$INITIALS','$PHONE','$FAX','$EMAIL','$COVER','$WORKGRP','$SCRNDUMP','$FAXTPL',$X1,$ABINUM
from "";
EOF
}

zapUser() {
#echo "Deleting $USERID"
$sqlcmd <<EOF
delete from "/edx/MENU.USER" where #1 = $USERID;
EOF
}

queryUser() {
if ! userExists $USERID
then
  echo "User $USERID does not exist."
  return 1
fi
#echo "Querying $USERID"
$sqlcmd <<EOF
select 
$GETGROUP $GETPRIV $GETNAME $GETMENU $GETMENUDIR $GETINITIALS
$GETPHONE $GETFAX $GETEMAIL $GETCOVER $GETWORKGRP $GETSCRNDUMP $GETFAXTPL
'' from "/edx/MENU.USER"
where #1 = $USERID
;
EOF
}

updateUser() {
if ! userExists $USERID
then
  echo "User $USERID does not exist."
  return 1
fi
#echo "Updating $USERID"
$sqlcmd <<EOF
update "/edx/MENU.USER" set
$SETGROUP $SETPRIV $SETNAME $SETMENU $SETMENUDIR $SETINITIALS
$SETPHONE $SETFAX $SETEMAIL $SETCOVER $SETWORKGRP $SETSCRNDUMP $SETFAXTPL
$SETABINUM
#1 = $USERID
where #1 = $USERID
;
EOF
}

copyUser() {
if ! userExists $USERID
then
  echo "User $USERID does not exist."
  return 1
fi
test -z "$COPYID" && echo "Error: Missing user to copy to." && usage && exit 1
#echo "Copying $USERID to $COPYID"
if ! userExists $COPYID
then
$sqlcmd <<EOF
insert into "/edx/MENU.USER"
select $COPYID,#2,#3,'$NAME',#5,#6,'$INITIALS',#8,#9,'$EMAIL',#11,#12,#13,$COPYID,#15,#16
from "/edx/MENU.USER"
where #1 = $USERID
;
EOF
else
  echo "Copy to user ($COPYID) already exists - delete user first."
fi
}

S=2	# default shift

while test $# -gt 0
do case "$1" in
-x) sqlcmd=cat; shift;;
-u) OP=update; shift;;
-a) OP=add; shift;;
-c) OP=copy; shift;;
-z) OP=zap; shift;;
-q) OP=query; S=1; shift;;
-g) GROUP="$2"; SETGROUP="#2 = $GROUP,"; GETGROUP="#2,"; shift $S;;
-v) PRIV="x'$2'"; SETPRIV="#3 = $PRIV,"; GETPRIV="#3,"; shift $S;;
-n) NAME="$2"; SETNAME="#4 = '$NAME',"; GETNAME="#4,"; shift $S;;
-m) MENU="$2"; SETMENU="#5 = '$MENU',"; GETMENU="#5,"; shift $S;;
-d) MENUDIR="$2"; SETMENUDIR="#6 = '$MENUDIR',"; GETMENUDIR="#6,"; shift $S;;
-i) INITIALS="$2"; SETINITIALS="#7 = '$INITIALS',"; GETINITIALS="#7,"; shift $S;;
-p) PHONE="$2"; SETPHONE="#8 = '$PHONE',"; GETPHONE="#8,"; shift $S;;
-f) FAX="$2"; SETFAX="#9 = '$FAX',"; GETFAX="#9,"; shift $S;;
-e) EMAIL="$2"; SETEMAIL="#10 = '$EMAIL',"; GETEMAIL="#10,"; shift $S;;
-c) COVER="$2"; SETCOVER="#11 = '$COVER',"; GETCOVER="#11,"; shift $S;;
-w) WORKGRP="$2"; SETWORKGRP="#12 = '$WORKGRP',"; GETWORKGRP="#12,"; shift $S;;
-s) SCRNDUMP="$2"; SETSCRNDUMP="#13 = '$SCRNDUMP',"; GETSCRNDUMP="#13,"; shift $S;;
-t) FAXTPL="$2"; SETFAXTPL="#14 = '$FAXTPL',"; GETFAXTPL="#14,"; shift $S;;
-b) ABINUM="$2"; SETABINUM="#16 = '$ABINUM',"; GETABINUM="#16,"; shift $S;;
*) USERID="$1"; shift; break;;
esac
done

USERID=$(userID $USERID)
test $# -gt 0 && COPYID="$1"
COPYID=$(userID $COPYID)

case "$OP" in
add) addUser;;
zap) zapUser;;
update) updateUser;;
query) queryUser;;
copy) copyUser;;
*) echo 'Operation not specified.  Specify -q, -u, -a, or -d';;
esac
